@@ -89,7 +89,7 @@ gnome_print_encode_rlc_wcs (gint size)
  * 
  * Return Value: size of the encodeed buffer
  **/
-#define _GNOME_PRINT_MAX_RUN_LENGTH_SIZE 256 /* Usefull for testing purposes */
+#define _GNOME_PRINT_MAX_RUN_LENGTH_SIZE 256 /* Useful for testing purposes */
 
 int
 gnome_print_encode_rlc (const guchar *in, guchar *out, gint in_size)
@@ -509,12 +509,16 @@ gnome_print_decode_hex_wcs (gint size)
 static inline gint
 hex_2_dec (guchar upper, guchar lower)
 {
-	if (upper > '9')
+	if (upper > '9') {
+		upper |= 0x20;
 		upper -= 39;
-	if (lower > '9')
+	}
+	if (lower > '9') {
+		lower |= 0x20;
 		lower -= 39;
+	}
 	       
-	return ((upper - '0')*16) + lower - '0';
+	return ((upper - '0') << 4) + lower - '0';
 }
 
 /**
@@ -724,7 +728,7 @@ gnome_print_decode_ascii85 (const guchar *in, guchar *out, gint in_size)
 	if ( (in [in_size-2] != '~') ||
 	     (in [in_size-1] != '>') ) {
 		in = g_strdup ("Ascii85 error. The buffer should end with ~>");
-		g_warning (in);
+		g_warning ("%s", in);
 		in_size = strlen (in);
  	}
 	
